<!-- omit in toc -->
# Recipes

Guides, tips and strategies for getting the most out of your Foam workspace!

- [Contribute](#contribute)
- [Take smart notes](#take-smart-notes)
- [Discover](#discover)
- [Organise](#organise)
- [Write](#write)
- [Version control](#version-control)
- [Publish](#publish)
- [Collaborate](#collaborate)
- [Workflow](#workflow)
- [Creative ideas](#creative-ideas)
- [Other](#other)

## Contribute

- Start by reading [[contribution-guide]]
- If you discover features not listed here, we'd love to have them! [[how-to-write-recipes]].

## Take smart notes

- Introduction to Zettelkasten [[todo]]
- Clip webpages with [[web-clipper]]

## Discover
- Explore your notes using [[graph-visualisation]]
- Discover relationships with [[backlinking]]
- Simulating [[unlinked-references]]

## Organise
- Using [[backlinking]] for [[reference-lists]].

## Write
- Link documents with [[wiki-links]], using Foam's [[link-formatting-and-autocompletion]].
- Use shortcuts for [[creating-new-notes]]
- Instantly create and access your [[daily-notes]]
- Use custom [[note-macros]] to create weekly, monthly etc. notes
- Draw [[diagrams-in-markdown]]
- Prettify your links, [[automatically-expand-urls-to-well-titled-links]]
- Style your environment with [[custom-markdown-preview-styles]]
- Paste and link [[images-from-your-clipboard]]
- [[shows-image-preview-on-hover]]
- [Markdown All-in-One](https://marketplace.visualstudio.com/items?itemName=yzhang.markdown-all-in-one) features [[todo]] [[good-first-task]]
  - Manage checklists
  - Automatic Table of Contents
  - Live preview markdown
  - _More..._
- VS Code Advanced Features [[todo]] [[good-first-task]]
  - Focus with Zen Mode

## Version control

- Quick commits with VS Code's built in [[git-integration]]
- Store your workspace in an auto-synced GitHub repo with [[gistpad]]
- Sync your GitHub repo automatically [[todo]].

## Publish

- Publish using official Foam template
  - Publish to [[github-pages]]
  - Publish to [[gitlab-pages]]
  - Publish to [[azure-devops-wiki]]
  - Publish to [[vercel]]
- Publish using community templates
  - [[eleventy-and-netlify]] by [@juanfrank77](https://github.com/juanfrank77)
  - [[foam-gatsby-template]] by [@mathieudutour](https://github.com/mathieudutour)
  - [foamy-nextjs](https://github.com/yenly/foamy-nextjs) by [@yenly](https://github.com/yenly)
- Make the site your own by [[customising-styles]].
- Render math symbols, by either
  - adding client-side [[math-support]] to the default [[github-pages]] site
  - adding a custom Jekyll plugin to support [[katex-math-rendering]]

## Collaborate

- Give your team push access to your GitHub repo [[todo]]
- Real-time collaboration via VS Code Live Share [[todo]]
- Accept patches via GitHub PRs [[todo]]

## Workflow

- Capture notes from Drafts app on iOS [[capture-notes-with-drafts-pro]]

## Creative ideas

Creative ideas welcome!

- Support [Anki](https://apps.ankiweb.net/) cards from notes like [Remnote](https://www.remnote.io/) [[todo]]

_See [[contribution-guide]] and [[how-to-write-recipes]]._

## Other

Thought of a recipe but don't see a category for them? Add them here and we'll organise them once we detect a theme.

_See [[contribution-guide]] and [[how-to-write-recipes]]._

[//begin]: # "Autogenerated link references for markdown compatibility"
[contribution-guide]: contribution-guide.md "Contribution Guide"
[how-to-write-recipes]: how-to-write-recipes.md "How to Write Recipes"
[todo]: todo.md "Todo"
[web-clipper]: web-clipper.md "Web Clipper"
[graph-visualisation]: graph-visualisation.md "Graph visualisation"
[backlinking]: backlinking.md "Backlinking"
[unlinked-references]: unlinked-references.md "Unlinked references (stub)"
[reference-lists]: reference-lists.md "Reference Lists"
[wiki-links]: wiki-links.md "Wiki Links"
[link-formatting-and-autocompletion]: link-formatting-and-autocompletion.md "Link Formatting and Autocompletion"
[creating-new-notes]: creating-new-notes.md "Creating New Notes"
[daily-notes]: daily-notes.md "Daily notes"
[note-macros]: note-macros.md "Custom Note Macros"
[diagrams-in-markdown]: diagrams-in-markdown.md "Diagrams in Markdown"
[automatically-expand-urls-to-well-titled-links]: automatically-expand-urls-to-well-titled-links.md "Automatically Expand URLs to Well-Titled Links"
[custom-markdown-preview-styles]: custom-markdown-preview-styles.md "Custom Markdown Preview Styles"
[images-from-your-clipboard]: images-from-your-clipboard.md "Images from your Clipboard"
[shows-image-preview-on-hover]: shows-image-preview-on-hover.md "Shows Image Preview on Hover"
[good-first-task]: good-first-task.md "Good First Task"
[git-integration]: git-integration.md "Git integration"
[gistpad]: gistpad.md "GistPad"
[github-pages]: github-pages.md "Github Pages"
[gitlab-pages]: gitlab-pages.md "GitLab Pages"
[eleventy-and-netlify]: eleventy-and-netlify.md "Eleventy and Netlify"
[azure-devops-wiki]: azure-devops-wiki.md "Azure DevOps Wiki"
[vercel]: vercel.md "Vercel"
[customising-styles]: customising-styles.md "Customising Styles"
[math-support]: math-support.md "Math Support"
[katex-math-rendering]: katex-math-rendering.md "Katex Math Rendering"
[capture-notes-with-drafts-pro]: capture-notes-with-drafts-pro.md "Capture Notes With Drafts Pro"
[foam-gatsby-template]: foam-gatsby-template.md "Foam Gatsby Template"
[//end]: # "Autogenerated link references"
